@@ -53,9 +53,9 @@ def _format(
     if subgraph_num > 1:
         for i in range(2, subgraph_num + 1):
             if fig.layout[f"xaxis{i}"].title.text is None:
-                warnings.warn("X-axis label of subgraph {} label not specified!")
+                warnings.warn(f"X-axis label of subgraph{i} label not specified!")
             if fig.layout[f"yaxis{i}"].title.text is None:
-                warnings.warn("Y-axis label of subgraph {} not specified!")
+                warnings.warn(f"Y-axis label of subgraph{i} not specified!")
 
             if fig.layout[f"xaxis{i}"].title.text is not None:
                 new_xlabel = " ".join(
